/*
 * FileName: TestServiceImpl
 * Author:   DONGSK
 * Datetime: 2022/8/24 13:40
 * Description:
 * History:
 * 作者姓名 --修改时间 --版本号--描述
 */
package com.digiwin.athena.app.provider.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.digiwin.app.service.DWServiceContext;
import com.digiwin.athena.app.infra.entity.LayoutConfig;
import com.digiwin.athena.app.infra.service.LayoutConfigService;
import com.digiwin.athena.app.provider.BasicApiService;
import com.digiwin.athena.app.service.basic.LoginService;
import com.digiwin.athena.opt.common.eai.service.EAIServiceContext;
import org.apache.commons.lang.StringUtils;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * TestServiceImpl
 *
 * @author DONGSK 2022/8/24 13:40
 * @since 1.0.0
 */
public class BasicApiServiceImpl implements BasicApiService {

    @Resource
    EAIServiceContext eaiServiceContext;

    @Resource
    LoginService loginService;

    @Resource
    LayoutConfigService layoutConfigService;

    @Override
    public String helloWord(String name) throws Exception {
        return "hello ," + name;
    }

    @Override
    public Object mockEAIExecutor(String serviceName, Map<String, Object> requestParameter) throws Exception {
        Map<String, String> headers = new HashMap<>();
        DWServiceContext.getContext().getRequestHeader().forEach((k, v) -> {
            headers.put(k, String.valueOf(v));
        });
        DWServiceContext.getContext().setStandardResult(false);
        /** 直接返回，不再包装，入参可以体现 serviceName
         Map<String, Object> eaiResult = new HashMap<>();
         eaiResult.put("service", serviceName);
         eaiResult.put("response", eaiServiceContext.execute(serviceName, headers, JSON.toJSONString(requestParameter)));
         */
        return eaiServiceContext.execute(serviceName, headers, JSON.toJSONString(requestParameter));
    }

    @Override
    public Object login(String userId, String tenantId, String productKey) throws Exception {
        return loginService.login(userId, tenantId, productKey);
    }

    @Override
    public Object clearLogin() throws Exception {
        loginService.clearLoginMap();
        return "ok";
    }

    @Override
    public Object layoutConfig(LayoutConfig layoutConfig) throws Exception {
        LambdaQueryChainWrapper<LayoutConfig> lambdaQuery = layoutConfigService.lambdaQuery()
                .eq(LayoutConfig::getUserId, layoutConfig.getUserId())
                .eq(LayoutConfig::getTenantId, layoutConfig.getTenantId())
                .eq(LayoutConfig::getSysId, layoutConfig.getSysId());
        if (lambdaQuery.exists()) {
            return layoutConfigService.lambdaUpdate()
                    .set(LayoutConfig::getTop, layoutConfig.getTop())
                    .set(LayoutConfig::getLeft, layoutConfig.getLeft())
                    .set(LayoutConfig::getWidth, layoutConfig.getWidth())
                    .set(LayoutConfig::getHeight, layoutConfig.getHeight())
                    .set(LayoutConfig::getTopPercent, layoutConfig.getTopPercent())
                    .set(LayoutConfig::getLeftPercent, layoutConfig.getLeftPercent())
                    .set(LayoutConfig::getWidthPercent, layoutConfig.getWidthPercent())
                    .set(LayoutConfig::getHeightPercent, layoutConfig.getHeightPercent())
                    .eq(LayoutConfig::getUserId, layoutConfig.getUserId())
                    .eq(LayoutConfig::getTenantId, layoutConfig.getTenantId())
                    .eq(LayoutConfig::getSysId, layoutConfig.getSysId())
                    .update();
        } else {
            return layoutConfigService.save(layoutConfig);
        }
    }

    @Override
    public Object layoutConfig(String userId, String tenantId, String sysId) throws Exception {

        LambdaQueryChainWrapper<LayoutConfig> lambdaQuery = layoutConfigService.lambdaQuery();
        lambdaQuery.eq(LayoutConfig::getUserId, userId);
        lambdaQuery.eq(LayoutConfig::getTenantId, tenantId);
        if (StringUtils.isNotBlank(sysId)) {
            lambdaQuery.eq(LayoutConfig::getSysId, sysId);
        }

        List<LayoutConfig> list = lambdaQuery.list();

        if (list.isEmpty()) {
            LambdaQueryChainWrapper<LayoutConfig> lambdaQueryX = layoutConfigService.lambdaQuery();
            lambdaQueryX.eq(LayoutConfig::getUserId, "default");
            lambdaQueryX.eq(LayoutConfig::getTenantId, tenantId);
            if (StringUtils.isNotBlank(sysId)) {
                lambdaQueryX.eq(LayoutConfig::getSysId, sysId);
            }
            list = lambdaQueryX.list();
        }

        return list;
    }

}
